==> knews-0.9.3.tar.gz: knews-0.9.3/Widgets/Message.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef _Message_h
#define _Message_h

#ifndef XtCBuffer
#define XtCBuffer "Buffer"
#endif
#ifndef XtCBufferLength
#define XtCBufferLength "BufferLength"
#endif
#ifndef XtCCenter
#define XtCCenter "Center"
#endif
#ifndef XtCInternalHeight
#define XtCInternalHeight "InternalHeight"
#endif
#ifndef XtCInternalWidth
#define XtCInternalWidth "InternalWidth"
#endif
#ifndef XtCPreferredChars
#define XtCPreferredChars "PreferredChars"
#endif

#ifndef XtNbuffer
#define XtNbuffer "buffer"
#endif
#ifndef XtNbufferLength
#define XtNbufferLength "bufferLength"
#endif
#ifndef XtNcenter
#define XtNcenter "center"
#endif
#ifndef XtNpreferredChars
#define XtNpreferredChars "preferredChars"
#endif


typedef struct _MessageClassRec*  MessageWidgetClass;
typedef struct _MessageRec*       MessageWidget;

extern WidgetClass messageWidgetClass;

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOBEGIN
#endif

extern void MessageSetAndRedraw(Widget, String, Boolean);

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOEND
#endif

#endif /* _Message_h */

==> knews-0.9.6-4.tar.gz: knews-0.9.6/Widgets/Message.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef Message_h
#define Message_h

#ifndef XtCBuffer
#define XtCBuffer "Buffer"
#endif
#ifndef XtCBufferLength
#define XtCBufferLength "BufferLength"
#endif
#ifndef XtCCenter
#define XtCCenter "Center"
#endif
#ifndef XtCInternalHeight
#define XtCInternalHeight "InternalHeight"
#endif
#ifndef XtCInternalWidth
#define XtCInternalWidth "InternalWidth"
#endif
#ifndef XtCPreferredChars
#define XtCPreferredChars "PreferredChars"
#endif

#ifndef XtNbuffer
#define XtNbuffer "buffer"
#endif
#ifndef XtNbufferLength
#define XtNbufferLength "bufferLength"
#endif
#ifndef XtNcenter
#define XtNcenter "center"
#endif
#ifndef XtNpreferredChars
#define XtNpreferredChars "preferredChars"
#endif


typedef struct MessageClassRec*  MessageWidgetClass;
typedef struct MessageRec*       MessageWidget;

extern WidgetClass messageWidgetClass;

extern void MessageSetAndRedraw(Widget, String, Boolean);

#endif /* Message_h */
